package com.zhugeio.zhuge;

import androidx.annotation.NonNull;
import com.zhuge.analysis.stat.ZhugeSDK;

import org.json.JSONObject;
import android.text.TextUtils;

import java.util.HashMap;
import java.util.List;
import java.util.Map;
import io.flutter.Log;

import io.flutter.embedding.engine.plugins.FlutterPlugin;
import io.flutter.plugin.common.BinaryMessenger;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import io.flutter.plugin.common.PluginRegistry.Registrar;

/** ZhugePlugin */
public class ZhugePlugin implements FlutterPlugin, MethodCallHandler {
  static final String ZhugeioAnalyticMethodIdentify = "identify";
  static final String ZhugeioAnalyticMethodTrack = "track";
  static final String ZhugeioAnalyticMethodTrackRevenue = "trackRevenue";
  static final String ZhugeioAnalyticMethodTrackStart = "trackStart";
  static final String ZhugeioAnalyticMethodTrackEnd = "trackEnd";
  static final String ZhugeioAnalyticMethodGetPlatformVersion = "getPlatformVersions";
  /** Plugin registration. */

  private static final String TAG = "ZhugeioPlugin == ";
  private MethodChannel channel;

  public static void registerWith(Registrar registrar) {
    final MethodChannel channel = new MethodChannel(registrar.messenger(), "zhugeio");
    channel.setMethodCallHandler(new ZhugePlugin());
  }


  @Override
  public void onMethodCall(@NonNull MethodCall call, @NonNull Result result) {

//    if (call.method.equals("getPlatformVersion")) {
//      result.success("Android " + android.os.Build.VERSION.RELEASE);
//    } else {
//      result.notImplemented();
//    }

    String method = call.method;
    List list = (List) call.arguments;
    if (null != list) {
      Log.i(TAG, list.toString());
    } else if (!method.equals(ZhugeioAnalyticMethodGetPlatformVersion)) {
      throw new RuntimeException("method " + method + " must have args");
    }

    switch (method) {
      case ZhugeioAnalyticMethodIdentify:

        trackIdentify(list);

        break;

      case ZhugeioAnalyticMethodTrack:

        track(list);

        break;

      case ZhugeioAnalyticMethodTrackRevenue:

        trackRevenue(list);

        break;

      case ZhugeioAnalyticMethodTrackStart:

        startTrack(list);

        break;

      case ZhugeioAnalyticMethodTrackEnd:
        endTrack(list);
        break;
      case ZhugeioAnalyticMethodGetPlatformVersion:
        result.success("Android " + android.os.Build.VERSION.RELEASE);
        break;

      default:
        result.notImplemented();
        break;

    }


  }

  /**
   * 标记用户
   *
   * @param =userId     用户ID
   * @param =properties 用户属性
   */
  private void trackIdentify(List list) {

    String userId = (String) list.get(0);
    HashMap<String, Object> properties = (HashMap) list.get(1);
//    Log.i(TAG,userId + properties.toString());
    ZhugeSDK.getInstance().identify(null, assertEventName(userId), properties);

  }

  /**
   * 追踪事件
   *
   * @param * eventName  事件名称
   * @param * properties 事件属性
   */
  private void track(List list) {
    String eventName = (String) list.get(0);
    HashMap<String, Object> properties = (HashMap) list.get(1);
//        Log.i(TAG,eventName + eventPro.toString());
    ZhugeSDK.getInstance().track(null, assertEventName(eventName), properties);
  }


  /**
   * 追踪收入事件
   *
   * @param * properties 收入事件属性
   */
  private void trackRevenue(List list) {
    HashMap<String, Object> revenuePro = (HashMap) list.get(0);
//        Log.i(TAG,revenuePro.toString());
    ZhugeSDK.getInstance().trackRevenue(null, revenuePro);
  }

  /**
   * 开始一个时长追踪事件，这个接口并不会真正的产生事件，当你调用{@link * endTrack(String, HashMap)}时，会在事件
   * 中添加一个duration属性，标记这个事件从调用这个接口开始所经过的时间，以秒为单位。
   *
   * @param =eventName 事件名称
   */
  private void startTrack(List list) {
    String eventName = (String) list.get(0);
    ZhugeSDK.getInstance().startTrack(assertEventName(eventName));
  }


  /**
   * 结束时长追踪，如果同样的event_name之前并没有调用{@link * startTrack(String)}，那么这个方法会立即返回。
   *
   * @param * eventName 事件名称，需在之前调用过startTrack
   * @param * properties 事件属性，可以为空。
   */
  private void endTrack(List list) {
    String eventName = (String) list.get(0);
    HashMap<String, Object> properties = (HashMap) list.get(1);
    JSONObject pro = new JSONObject(properties);
    ZhugeSDK.getInstance().endTrack(assertEventName(eventName), pro);
  }

  private String assertEventName(String eventName) {
    if (TextUtils.isEmpty(eventName)) {
      Log.d(TAG, "事件名为空，请检查代码");
    }
    return eventName;
  }


  private JSONObject assertProperties(Map map) {
    if (map != null) {
      return new JSONObject(map);
    } else {
      Log.d(TAG, "传入的属性为空");
      return null;
    }
  }

  @Override
  public void onDetachedFromEngine(@NonNull FlutterPluginBinding binding) {
    channel.setMethodCallHandler(null);
  }

  @Override
  public void onAttachedToEngine(@NonNull FlutterPluginBinding flutterPluginBinding) {
    channel = new MethodChannel(flutterPluginBinding.getBinaryMessenger(), "zhuge");
    channel.setMethodCallHandler(this);
  }

  private void privateOnAttachedToEngine(BinaryMessenger messenger) {
    channel = new MethodChannel(messenger, "zhugeio");
    channel.setMethodCallHandler(this);
  }

}


