#import "ZhugePlugin.h"
#import "Zhuge.h"

static NSString * const ZhugeioAnalyticsMethodIdentify = @"identify";
static NSString * const ZhugeioAnalyticsMethodTrack = @"track";
static NSString * const ZhugeioAnalyticsMethodTrackRevenue = @"trackRevenue";
static NSString * const ZhugeioAnalyticsMethodTrackStart = @"trackStart";
static NSString * const ZhugeioAnalyticsMethodTrackEnd = @"trackEnd";

@implementation ZhugePlugin
+ (void)registerWithRegistrar:(NSObject<FlutterPluginRegistrar>*)registrar {
  FlutterMethodChannel* channel = [FlutterMethodChannel
      methodChannelWithName:@"zhuge"
            binaryMessenger:[registrar messenger]];
  ZhugePlugin* instance = [[ZhugePlugin alloc] init];
  [registrar addMethodCallDelegate:instance channel:channel];
}

- (void)handleMethodCall:(FlutterMethodCall*)call result:(FlutterResult)result {
    
    NSString* method = call.method;
    NSArray* arguments = (NSArray *)call.arguments;
    if ([@"getPlatformVersion" isEqualToString:call.method]) {
        
        result([@"iOS " stringByAppendingString:[[UIDevice currentDevice] systemVersion]]);
        
    } else if ([method isEqualToString:ZhugeioAnalyticsMethodIdentify]) {
        
        NSString *event = arguments[0];
        argumentSetNSNullToNil(&event);
//        NSDictionary *properties = arguments[1];
        NSMutableDictionary *properties = [[NSMutableDictionary alloc] initWithDictionary:arguments[1]];
        NSLog(@"%@ == %@",event,properties);
        argumentSetNSNullToNil(&properties);
        [self identify:event properties:properties];
        result(nil);
        
    } else if ([method isEqualToString:ZhugeioAnalyticsMethodTrack]) {
        
        NSString *event = arguments[0];
        argumentSetNSNullToNil(&event);
        NSMutableDictionary *properties = [[NSMutableDictionary alloc] initWithDictionary:arguments[1]];
        argumentSetNSNullToNil(&properties);
        [self track:event properties:properties];
        result(nil);
        
    } else if ([method isEqualToString:ZhugeioAnalyticsMethodTrackRevenue]) {
        
        NSMutableDictionary *properties = [[NSMutableDictionary alloc] initWithDictionary:arguments[0]];
        NSString *price = [NSString stringWithFormat:@"%@",properties[ZhugeEventRevenuePrice]];
        NSString *number = [NSString stringWithFormat:@"%@",properties[ZhugeEventRevenueProductQuantity]];
        if (price.length == 0 || number.length == 0) {
            NSLog(@"价格和数量不能为空");
            result(nil);
            return;
        }
        [self trackRevenue:properties];
        result(nil);
        
    } else if ([method isEqualToString:ZhugeioAnalyticsMethodTrackStart]) {
        
        NSString *event = arguments[0];
        argumentSetNSNullToNil(&event);
        [self startTrack:event];
        result(nil);
        
    } else if ([method isEqualToString:ZhugeioAnalyticsMethodTrackEnd]) {
        
        NSString *event = arguments[0];
        argumentSetNSNullToNil(&event);
//        NSDictionary *properties = arguments[1];
        NSMutableDictionary *properties = [[NSMutableDictionary alloc] initWithDictionary:arguments[1]];
        argumentSetNSNullToNil(&properties);
        [self endTrack:event properties:properties];
        result(nil);
    } else {
        result(FlutterMethodNotImplemented);
    }
}


/**
 标识用户。
 @param userId     用户ID
 @param properties 用户属性
 */
- (void)identify:(nonnull NSString*)userId properties:(nullable   NSDictionary *)properties {
    [[Zhuge sharedInstance] identify:userId properties:properties];
}

/**
 * 只追踪自定义事件
 */
- (void)track:(nonnull NSString *)eventName {
    [[Zhuge sharedInstance] track:eventName];
}

/**
 *追踪自定义事件。
 * @param eventName  事件名称
 * @param properties 事件属性
 */
- (void)track:(NSString *)eventName properties:(nullable NSDictionary *)properties {
    [[Zhuge sharedInstance] track:eventName properties:properties];
}

/** 追踪收入事件
 *  @param properties 事件属性
 */
- (void)trackRevenue:(nullable NSDictionary *)properties {
    [[Zhuge sharedInstance] trackRevenue:properties];
}

/**
 开始追踪一个耗时事件，这个借口并不会真正的统计这个事件。当你调用endTrack时，会统计两个接口之间的耗时，
 并作为一个属性添加到事件之中
 @param eventName 事件名称
 */
- (void)startTrack:(nonnull NSString *)eventName {
    [[Zhuge sharedInstance] startTrack:eventName];
}
- (void)endTrack:(nonnull NSString *)eventName properties:(nullable NSDictionary *)properties {
    [[Zhuge sharedInstance] endTrack:eventName properties:properties];
}


static inline void argumentSetNSNullToNil(id *arg){
    *arg = (*arg == NSNull.null) ? nil:*arg;
}

@end
