
import 'dart:async';

import 'package:flutter/services.dart';

class Zhuge {
  static const MethodChannel _channel = MethodChannel('zhuge');

  static Future<String?> get platformVersion async {
    final String? version = await _channel.invokeMethod('getPlatformVersion');
    return version;
  }

  /// 标识用户。
  /// @param userId     用户ID
  /// @param properties 用户属性

  static void identify(String userId, Map properties) {
    assert(userId != null);
    List params = [userId, properties];
    _channel.invokeListMethod('identify',params);
  }

  ///  track 事件追踪
  /// @param eventName
  /// @param properties Map<String, dynamic> 事件属性

  static void track(String eventName, Map properties) {
    assert(eventName != null);
    List params = [eventName, properties];
    _channel.invokeListMethod('track', params);
  }

  ///  track 收入事件追踪
  /// @param properties Map<String, dynamic> 事件属性
  ///
  static void trackRevenue(Map properties) {
    assert(properties != null);
    List params = [properties];
    _channel.invokeListMethod('trackRevenue',params);
  }

  ///开始追踪一个耗时事件，这个借口并不会真正的统计这个事件。当你调用endTrack时，会统计两个接口之间的耗时，
  ///并作为一个属性添加到事件之中
  ///@param eventName 事件名称
  ///
  static void startTrack(String eventName) {
    assert(eventName != null);
    List params = [eventName];
    _channel.invokeListMethod('trackStart',params);
  }

  static void endTrack(String eventName, Map properties) {
    assert(eventName != null);
    List params = [eventName, properties];
    _channel.invokeListMethod('trackEnd',params);
  }

}
